@@ -1,4 +1,7 @@
 """CLI for ``tmuxp shell`` subcommand."""
+
+from __future__ import annotations
+
 import argparse
 import os
 import pathlib
@@ -6,8 +9,8 @@ import typing as t
 
 from libtmux.server import Server
 
-from .. import util
-from .._compat import PY3, PYMINOR
+from tmuxp import util
+from tmuxp._compat import PY3, PYMINOR
 
 if t.TYPE_CHECKING:
     from typing_extensions import TypeAlias
@@ -28,13 +31,13 @@ class CLIShellNamespace(argparse.Namespace):
     """Typed :class:`argparse.Namespace` for tmuxp shell command."""
 
     session_name: str
-    socket_name: t.Optional[str]
-    socket_path: t.Optional[str]
-    colors: t.Optional["CLIColorsLiteral"]
-    log_file: t.Optional[str]
-    window_name: t.Optional[str]
-    command: t.Optional[str]
-    shell: t.Optional["CLIShellLiteral"]
+    socket_name: str | None
+    socket_path: str | None
+    colors: CLIColorsLiteral | None
+    log_file: str | None
+    window_name: str | None
+    command: str | None
+    shell: CLIShellLiteral | None
     use_pythonrc: bool
     use_vi_mode: bool
 
@@ -146,7 +149,7 @@ def create_shell_subparser(parser: argparse.ArgumentParser) -> argparse.Argument
 
 def command_shell(
     args: CLIShellNamespace,
-    parser: t.Optional[argparse.ArgumentParser] = None,
+    parser: argparse.ArgumentParser | None = None,
 ) -> None:
     """Entrypoint for ``tmuxp shell`` for tmux server, session, window and pane.
 
@@ -154,8 +157,8 @@ def command_shell(
 
     - session_name and window_name arguments
     - current shell: envvar ``TMUX_PANE`` for determining window and session
-    - :attr:`libtmux.Server.attached_sessions`, :attr:`libtmux.Session.attached_window`,
-      :attr:`libtmux.Window.attached_pane`
+    - :attr:`libtmux.Server.attached_sessions`, :attr:`libtmux.Session.active_window`,
+      :attr:`libtmux.Window.active_pane`
     """
     # If inside a server, detect socket_path
     env_tmux = os.getenv("TMUX")
@@ -190,24 +193,23 @@ def command_shell(
 
     if args.command is not None:
         exec(args.command)
+    elif args.shell == "pdb" or (
+        os.getenv("PYTHONBREAKPOINT") and PY3 and PYMINOR >= 7
+    ):
+        from tmuxp._compat import breakpoint as tmuxp_breakpoint
+
+        tmuxp_breakpoint()
+        return
     else:
-        if args.shell == "pdb" or (
-            os.getenv("PYTHONBREAKPOINT") and PY3 and PYMINOR >= 7
-        ):
-            from tmuxp._compat import breakpoint as tmuxp_breakpoint
+        from tmuxp.shell import launch
 
-            tmuxp_breakpoint()
-            return
-        else:
-            from ..shell import launch
-
-            launch(
-                shell=args.shell,
-                use_pythonrc=args.use_pythonrc,  # shell: code
-                use_vi_mode=args.use_vi_mode,  # shell: ptpython, ptipython
-                # tmux environment / libtmux variables
-                server=server,
-                session=session,
-                window=window,
-                pane=pane,
-            )
+        launch(
+            shell=args.shell,
+            use_pythonrc=args.use_pythonrc,  # shell: code
+            use_vi_mode=args.use_vi_mode,  # shell: ptpython, ptipython
+            # tmux environment / libtmux variables
+            server=server,
+            session=session,
+            window=window,
+            pane=pane,
+        )
